(guide)=

# User Guide

The following pages give some background on the context within which `jaxoplanet`
exists, as well as detailed installation and API documentation. Click through
for all the details, or head over to the {ref}`tutorials` for a more hands-on
experience.

```{toctree}
:maxdepth: 1

install
troubleshooting
```
